@@ -5,6 +5,7 @@ __all__ = ['load_pbn', 'save_pbn', 'load_lin', 'load_rbn', 'parse_pbn', 'parse_l
 import os
 import datetime
 import re
+import uuid 
 
 from .event import Event
 from .board import Board
@@ -41,6 +42,7 @@ RBN_CREATOR_TEXT = '% Created by bridgeobjects'
 DEFAULT_EVENT_NAME = 'BfG default event name'
 DEFAULT_EVENT_DATE = datetime.date(1980, 1, 1)
 
+DUMMY_EVENT = uuid.uuid1()
 
 def load_pbn(path):
     """Load a pbn file to a list of events."""
@@ -109,6 +111,7 @@ def parse_pbn(file_lines):
     play_state = False
     board_state = False
     events = []
+    event = None
     board = None
     value = None
     for line in file_lines:
@@ -126,9 +129,11 @@ def parse_pbn(file_lines):
                     if board_state and tag == 'Description':
                         board.description = value
                         board_state = False
-
+                        
             # Event event
             if tag == "Event":
+                if not value:
+                    value = DUMMY_EVENT
                 if current_name != value:
                     current_name = value
                     current_board_identifier = ""
@@ -159,7 +164,6 @@ def parse_pbn(file_lines):
                         event = Event(DEFAULT_EVENT_NAME)
                         events.append(event)
                     event.boards.append(board)
-                    # print('xxx', event, events)
                     trick_index = 0
 
             # Board West
@@ -260,7 +264,7 @@ def _parse_pbn_line(line):
 def _parse_pbn_date(value):
     """Return a datetime date object from a pbn date string."""
     # example date value: 2018.02.26
-    is_valid = re.search("[0-9]{4}\.[\0-9]{2}\.[0-9]{2}", value)
+    is_valid = re.search("[0-9]{4}.[\0-9]{2}.[0-9]{2}", value)
     if is_valid:
         date = value.split('.')
         date = list(map(int, date))
@@ -894,3 +898,4 @@ class BoardAsString(object):
             output.append('')
         print(output)
         return output
+
