@@ -2,6 +2,7 @@
 
 
 from .card import Card
+from .denomination import Denomination
 from .suit import Suit, Spades, Hearts, Diamonds, Clubs
 from .constants import (SUIT_NAMES, RANKS, SUITS, HONOUR_POINTS,
                         BALANCED_SHAPES, SEMI_BALANCED_SHAPES,
@@ -788,7 +789,7 @@ class Hand(object):
     def _get_suit_points(self, suit):
         """Return the high card points for the suit."""
         suit_points = 0
-        if isinstance(suit, Suit):
+        if isinstance(suit, Suit) or isinstance(suit, Denomination):
             suit_name = suit.name
         else:
             suit_name = suit
@@ -907,3 +908,4 @@ class Hand(object):
                 if ten in cards and nine in cards:
                     internal_sequences.append(ten)
         return internal_sequences
+
